# $Id: L440GX_sensor.py,v 1.1 1999/12/07 17:57:02 cvs Exp $

""" Dictionary for decoding sensor codes on Intel L440GX+ motherboard """

sensor_dict = {
    0x01: {
        None: 'Temperature',
        0x01: 'Backplane Temperature',
        0x17: 'Primary Processor Temperature',
        0x18: 'Secondary Processor Temperature',
        0x19: 'Baseboard Temperature 1',
        0x1A: 'Baseboard Temperature 2', },
    0x02: {
        None: 'Voltage',
        0x01: 'Baseboard 5V',
        0x02: 'Baseboard 3.3V',
        0x03: 'Primary Processor Voltage',
        0x04: 'Secondary Processor Voltage',
        0x05: 'Processor 2.5V',
        0x06: '5V Standby',
        0x07: 'Baseboard SCSI-W LVDS Term1 Voltage',
        0x08: 'Baseboard SCSI-W LVDS Term2 Voltage',
        0x09: '3V Standby (Wake On LAN)',
        0x0A: 'Baseboard -12V',
        0x0B: 'Baseboard SCSI-W SGL Term Voltage',
        0x0C: 'Processor 1.5V',
        0x0D: 'Baseboard -5V',
        0x0E: 'Baseboard +12V', },
    0x04: {
        None: 'Fan',
        0x0C: 'Backplane Fan 1',
        0x0D: 'Backplane Fan 2',
        0x0F: 'Baseboard Fan 0',
        0x10: 'Baseboard Fan 1',
        0x11: 'Processor Fan 0',
        0x12: 'Processor Fan 1',
        0x1F: 'Digital Fan 1',
        0x20: 'Digital Fan 2',
        0x21: 'Digital Fan 3',
        0x22: 'Digital Fan 4', },
    0x05: {
        None: 'Physical Security',
        0x26: 'Chassis intrusion', },
    0x06: {
        None: 'Secure Mode Sensor',
        0x27: 'EMP Password',
        0x28: 'Secure Mode Sensor', },
    0x07: {
        None: 'Processor',
        0x1B: 'Primary Processor Status',
        0x1C: 'Secondary Processor Status',},
    0x09: {
        None: 'Power Supply',
        0x29: 'Power Supply',
        0xEF: 'Power Supply', },
    0x0C: {
        None: 'Memory',
        0xEF: 'Memory', },
    0x0D: {
        None: 'Drive Slot (Bay)',
        0x02: 'Drive Slot 0 Status',
        0x03: 'Drive Slot 1 Status',
        0x04: 'Drive Slot 2 Status',
        0x05: 'Drive Slot 3 Status',
        0x06: 'Drive Slot 4 Status',
        0x07: 'Drive Slot 0 Presence',
        0x08: 'Drive Slot 1 Presence',
        0x09: 'Drive Slot 2 Presence',
        0x0A: 'Drive Slot 3 Presence',
        0x0B: 'Drive Slot 4 Presence', },
    0x0F: {
        None: "POST",
        0x25: "POST",},
    0x11: {
        None: 'Watchdog',
        0x1D: 'BMC Watchdog',},
    0x12: {
        None: 'System Event',
        0xEF: 'System Event',},
    0x13: {
        None: 'Critical Interrupt',
        0x1E: 'Front Panel NMI',},
    }

        
bios_dict = {
    0x12: {
        0x01: 'System Boot',
        0x00: 'System Reconfiguration',},
    0x0C: {
        0x40: 'Single Bit Memory Error',
        0x41: 'Multi-Bit Memory Error',
        0x02: 'Memory Parity Error',},
    0x13: {
        0x01: 'Bus Timeout',
        0x02: 'I/O CHK',
        0x03: 'Software NMI',
        0x04: 'PCI PERR',}
    }

post_dict = {
    (0x00,0x02): 'Failure Fixed Disk',
    (0x00,0x81): 'processor 0 failed BIST',
    (0x01,0x04): 'Invalid System Configuration Data - run configuration utility',
    (0x01,0x06): 'Device configuration changed',
    (0x01,0x81): 'processor 1 failed BIST',
    (0x02,0x06): 'Configuration error - device disabled',
    (0x03,0x04): 'Resource Conflict',
    (0x04,0x04): 'Resource Conflict',
    (0x04,0x05): 'Resource Conflict',
    (0x04,0x81): 'processor 0 Internal Error (IERR) failure',
    (0x05,0x04): 'Expansion ROM not initialized',
    (0x05,0x05): 'Expansion ROM not initialized',
    (0x05,0x81): 'processor 1 Internal Error (IERR) failure',
    (0x06,0x04): 'Warning: IRQ not configured',
    (0x06,0x05): 'Warning: IRQ not configured',
    (0x06,0x81): 'processor 0 Thermal Trip failure',
    (0x07,0x81): 'processor 1 Thermal Trip failure',
    (0x08,0x81): 'Watchdog Timer failed on last boot, BSP switched.',
    (0X0A,0X81): 'processor 1 failed initialization on last boot.',
    (0X0B,0X81): 'processor 0 failed initialization on last boot.',
    (0X0C,0X81): 'processor 0 disabled, system in Uni-processor mode',
    (0X0D,0X81): 'processor 1 disabled, system in Uni-processor mode',
    (0X0E,0X81): 'processor 0 failed FRB Level 3 timer',
    (0X0F,0X81): 'processor 1 failed FRB Level 3 timer',
    (0x10,0x02): 'Stuck Key',
    (0x10,0x81): 'Server Management Interface failed to function',
    (0x11,0x02): 'Keyboard error',
    (0x12,0x02): 'Keyboard Controller Failed',
    (0x13,0x02): 'Keyboard locked - Unlock key switch',
    (0x20,0x02): 'Monitor type does not match CMOS - Run SETUP',
    (0x20,0x81): 'IOP sub-system is not functional',
    (0x30,0x02): 'System RAM Failed at offset:',
    (0x31,0x02): 'Shadow Ram Failed at offset:',
    (0x32,0x02): 'Extended RAM Failed at offset:',
    (0x50,0x02): 'System battery is dead - Replace and run SETUP',
    (0x50,0x81): 'NVRAM Cleared by Jumper',
    (0x51,0x02): 'System CMOS checksum bad - Default configuration used',
    (0x51,0x81): 'NVRAM Checksum Error, NVRAM cleared',
    (0x52,0x81): 'NVRAM Data Invalid, NVRAM cleared',
    (0x60,0x02): 'System timer error',
    (0x62,0x01): 'BIOS unable to apply BIOS update to processor 1',
    (0x63,0x01): 'BIOS unable to apply BIOS update to processor 2',
    (0x64,0x01): 'BIOS does not support current stepping for processor 1',
    (0x65,0x01): 'BIOS does not support current stepping for processor 2',
    (0x70,0x02): 'Real time clock error',
    (0x97,0x02): 'ECC Memory error in base (extended) memory test in Bank xx',
    (0xB2,0x02): 'Incorrect Drive A type - run SETUP',
    (0xB3,0x02): 'Incorrect Drive B type - run SETUP',
    (0xD0,0x02): 'System cache error - Cache disabled',
    (0xF5,0x02): 'DMA Test Failed',
    (0xF6,0x02): 'Software NMI Failed',}




    
